@@ -15,11 +15,19 @@ var INC = (isNode ? require.paths : []).concat('../lib', '/jsan')
 Harness.configure({
     title     : '{{ $plugin->dist_name }} Test Suite',
     
-    preload : [
+    preload : Joose.is_NodeJS ? [
         "jsan:Task.Joose.Core",
-        "jsan:Task.JooseX.Namespace.Depended.Auto",
+        "jsan:Task.JooseX.Namespace.Depended.NodeJS",
         {
-            text : "JooseX.Namespace.Depended.Manager.my.INC = " + Joose.is_NodeJS ? JSON.stringify(INC) : Ext.encode(Harness.absolutizeINC(INC))
+            text : "JooseX.Namespace.Depended.Manager.my.INC = " + JSON.stringify(INC)
+        }
+        
+    ] : [
+        "jsan:Task.Joose.Core",
+        "jsan:JooseX.SimpleRequest",
+        "jsan:Task.JooseX.Namespace.Depended.Web",
+        {
+            text : "JooseX.Namespace.Depended.Manager.my.INC = " + Ext.encode(Harness.absolutizeINC(INC))
         }
     ]
 })
